***********************
:mod:`mopidy.frontends`
***********************

A frontend is responsible for exposing Mopidy for a type of clients.


Frontend API
============

A stable frontend API is not available yet, as we've only implemented a single
frontend module.


Frontends
=========

* :mod:`mopidy.frontends.mpd`
